import { Rule } from "@/components/rule";
import Image from "next/image";

const Manual = (): JSX.Element => {
  return (
    <>
      <main className="w-4/5 text-center max-w-4xl m-auto mt-16 mb-16 rounded-lg">
        <h1 className="text-5xl">Naomi&apos;s User Manual</h1>
        <p className="text-3xl">Model T42-P9000</p>
        <section>
          <p className="mb-2">
            Hiya! This page is meant to give you a run-down of what working with
            me is like. It&apos;s like a li&apos;l insight into the way I best
            interact with people and perform on a team.
          </p>
          <Image
            className="m-auto"
            src="https://cdn.nhcarrigan.com/hire.jpeg"
            alt="If you knew I was so unstable, why'd you hire me?"
            width={500}
            height={500}
          />
          <Rule />
        </section>
        <section>
          <h2 className="text-3xl">My Values</h2>
          <p className="mb-2">
            I tend to be very firm in my values, to the degree that I shy away
            from organisations or projects which do not align with my ethics.
          </p>
          <ul className="w-4/5 m-auto">
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              First and foremost, do not pass judgement. I will not begrudge you
              for your religious beliefs, political alignments, or any other
              aspects of your life. And I expect the same courtesy in return.
              You do not have to accept who I am, or support my choices, but we
              need to maintain a respectful and cordial professional
              relationship. Expressing hateful, mean-spirited, or vitriolic
              comments does not foster such an environment, and my tolerance for
              such is nil.
            </li>
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              Second, we shall do no harm. I very strongly believe that
              technology is meant to advance our society, not regress it.
              Software should not be used to automate people&apos;s careers
              away, or replace creative works with pale imitations, or
              harass/target someone, or restrict access to information.
            </li>
          </ul>
          <Rule />
        </section>
        <section>
          <h2 className="text-3xl">Environment</h2>
          <p className="mb-2">
            I have found that I best thrive and produce the greatest works in
            specific environments.
          </p>
          <ul className="w-4/5 m-auto">
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              Ideas should be freely discussed, challenged, and evaluated. I am
              not a &quot;yes girl&quot; to blindly follow orders. If I hear a
              plan that I think misses the mark, I will absolutely voice my
              concerns. And I welcome the same scrutiny in return. Discussion
              needs to be constructive and fruitful - if we&apos;re going around
              in circles, it&apos;s time to table it and sleep on our thoughts.
            </li>
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              We are not our ideas, however. &quot;This is bad and you should
              feel bad&quot; helps no one. &quot;I&apos;m not sure that is the
              best approach, can we consider doing this instead?&quot; keeps the
              conversation focused on the right things and moving forward.
            </li>
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              ADHD means my productivity is highly fluctuating. There are days
              where I can sit and bang out a week of work in 16 hours, and there
              are days where I stare mindlessly at the screen and then realise
              the sun has set already. Flexibility in both schedule and
              deadlines is very important to me.
            </li>
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              Likewise, insomnia can rear its ugly head and absolutely wreck my
              sleep schedule without any warning. Asynchronous comms are always
              preferred over meetings, but if a meeting must happen the
              afternoon hours are the best. Too early and I&apos;ll likely fail
              to wake up. Too late and I might be incoherent.
            </li>
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              If given something like a Trello or a Monday board, I will 100%
              make it pretty and load every single task ever on there. I&apos;m
              a sucker for organising workloads and the easiest way for me to be
              transparent about the work I&apos;m doing is to just let you look
              at a task board. If you say &quot;what did you do yesterday&quot;
              I will not remember this for I have slept since then.
            </li>
          </ul>
          <Rule />
        </section>
        <section>
          <h2 className="text-3xl">Communication</h2>
          <p>
            As with many people, there are certain approaches to communication
            that are more effective for me.
          </p>
          <ul className="w-4/5 m-auto">
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              Don&apos;t just say &quot;hello&quot; in my DMs or ping me without
              context. You&apos;ll pull me out of a workflow to wait for the
              rest of the message. Send it all at once, or save the ping for the
              last part.
            </li>
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              I have generalised anxiety disorder. Please for the love of all
              things, do NOT say &quot;we need to talk&quot; or &quot;do you
              have time to meet&quot;. I will 100% sit there right up until the
              meeting starts stressing about getting fired and not actually
              getting any work done. If you need to call me out, just rip the
              bandage off and come out of the gate with it.
            </li>
            <li className="mb-2 relative before:content-['🩵'] before:absolute before:left-[-1em]">
              I dunno if you noticed the tone changed in this document about a
              million times. That&apos;s pretty much Naomi in a nutshell.
              I&apos;ll go from collected and eloquent to manic and sending
              messages faster than Discord can process. I try my hardest to stay
              professional, but ADHD makes that very hard. I&apos;ll swear
              sometimes, I&apos;ll say totally off-the-wall things. But I really
              do try!
            </li>
          </ul>
        </section>
      </main>
    </>
  );
};

export default Manual;
